import { StrictMode } from 'react';
import { createRoot } from 'react-dom/client';
import { Toaster } from 'sonner';

import { createBrowserRouter, RouterProvider } from 'react-router-dom';

import './index.css';

// Pages
import App from './App.jsx';
import Landing from './pages/Landing';
import About from './pages/About';
import Contact from './pages/Contact';
import Login from './pages/Login';
import Register from './pages/Register';
import Menu from './pages/Menu';
import MenuItem from './pages/MenuItem';
import ErrorPage from './pages/Error';
import Cart from './pages/Cart';
import Orders from './pages/Orders';

const router = createBrowserRouter([
  {
    path: '/',
    element: <App />,
    errorElement: <ErrorPage />,
    children: [
      {
        path: '/',
        element: <Landing />,
      },
      {
        path: '/about',
        element: <About />,
      },
      {
        path: '/contact',
        element: <Contact />,
      },
      {
        path: '/login',
        element: <Login />,
      },
      {
        path: '/register',
        element: <Register />,
      },
      {
        path: '/cart',
        element: <Cart />,
      },
      {
        path: '/orders',
        element: <Orders />,
      },
      {
        path: '/menu',
        element: <Menu />,
      },
      {
        path: '/menu/:id',
        element: <MenuItem />,
      },
    ],
  },
]);

createRoot(document.getElementById('root')).render(
  <StrictMode>
    <Toaster position='top-center' richColors theme='light' />
    <RouterProvider router={router} />
  </StrictMode>
);
